{*******************************************************************************
   Ttulo: CNotaFiscal
Descrio: Classe responsvel pelas expecificaes de Nota Fiscal de Sada.
           Exerce o papel de Context dentro do padro Strategy.
            nessa classe que acontece a deciso de qual estratgia ser
           utilizada para o calculo dos impostos.
    Autor: David Pagliotto
  Contato: david_pagliotto@hotmail.com
*******************************************************************************}

unit CNotaFiscalSaida;

interface

uses
  Forms, Windows, SysUtils,
  ICalculoImposto;

type
  TNotaFiscalSaida = class
  private
    FTipoNotaFiscalSaida: String; //EX - Exportao | DE - Dentro do Estado | FE - Fora do Estado
    FCalculoImposto: TICalculoImposto;
  published
    property TipoNotaFiscalSaida: String read FTipoNotaFiscalSaida write FTipoNotaFiscalSaida;
    procedure ExecutaCalculoImposto();
end;

implementation

uses
  CCalculoDentroDoEstado, CCalculoExportacao, CCalculoForaDoEstado;

procedure TNotaFiscalSaida.ExecutaCalculoImposto();
begin
  try
    if (FTipoNotaFiscalSaida = 'EX') then
    begin
      FCalculoImposto := TCalculoExportacao.Create;
      FCalculoImposto.CalcularImposto();
    end
    else if (FTipoNotaFiscalSaida = 'DE') then
    begin
      FCalculoImposto := TCalculoDentroDoEstado.Create;
      FCalculoImposto.CalcularImposto();
    end
    else if (FTipoNotaFiscalSaida = 'FE') then
    begin
      FCalculoImposto := TCalculoForaDoEstado.Create;
      FCalculoImposto.CalcularImposto();
    end
    else
    begin
      Application.MessageBox('No foi informado um Tipo de Nota Fiscal de Sada vlido!',
                             '..:: Ateno ::..', MB_ICONWARNING + MB_OK);
    end;
  finally
    FreeAndNil(FCalculoImposto);
  end;
end;

end.

